@@ -1,2 +1,2 @@
-from .get_data import get_edges_data
+from .get_data import get_vis_data
 from .render_template import render_html_vis
